==> lyx-1.6.9.tar.gz: lyx-1.6.9/src/lyxinsets.cpp <==

#include "insets/ExternalSupport.cpp" 
#include "insets/ExternalTemplate.cpp" 
#include "insets/ExternalTransforms.cpp" 
#include "insets/RenderButton.cpp" 
#include "insets/RenderGraphic.cpp" 
#include "insets/RenderPreview.cpp" 
#include "insets/Inset.cpp" 
#include "insets/InsetBibitem.cpp" 
#include "insets/InsetBibtex.cpp" 
#include "insets/InsetBox.cpp" 
#include "insets/InsetBranch.cpp" 
#include "insets/InsetCaption.cpp" 
#include "insets/InsetCitation.cpp" 
#include "insets/InsetCollapsable.cpp" 
#include "insets/InsetCommand.cpp" 
#include "insets/InsetCommandParams.cpp" 
#include "insets/InsetERT.cpp" 
#include "insets/InsetExternal.cpp" 
#include "insets/InsetFlex.cpp" 
#include "insets/InsetFloat.cpp" 
#include "insets/InsetFloatList.cpp" 
#include "insets/InsetFoot.cpp" 
#include "insets/InsetFootlike.cpp" 
#include "insets/InsetGraphicsParams.cpp" 
#include "insets/InsetGraphics.cpp" 
#include "insets/InsetHyperlink.cpp" 
#include "insets/InsetInclude.cpp" 
#include "insets/InsetIndex.cpp" 
#include "insets/InsetInfo.cpp" 
#include "insets/InsetLabel.cpp" 
#include "insets/InsetLayout.cpp" 
#include "insets/InsetLine.cpp" 
#include "insets/InsetListings.cpp" 
#include "insets/InsetListingsParams.cpp" 
#include "insets/InsetMarginal.cpp" 
#include "insets/InsetNewline.cpp" 
#include "insets/InsetNewpage.cpp" 
#include "insets/InsetNomencl.cpp" 
#include "insets/InsetNote.cpp" 
#include "insets/InsetOptArg.cpp" 
#include "insets/InsetQuotes.cpp" 
#include "insets/InsetRef.cpp" 
#include "insets/InsetSpace.cpp" 
#include "insets/InsetSpecialChar.cpp" 
#include "insets/InsetTabular.cpp" 
#include "insets/InsetText.cpp" 
#include "insets/InsetTOC.cpp" 
#include "insets/InsetVSpace.cpp" 
#include "insets/InsetWrap.cpp"

==> lyx-2.0.8.tar.gz: lyx-2.0.8/src/lyxinsets.cpp <==

#include "insets/ExternalSupport.cpp" 
#include "insets/ExternalTemplate.cpp" 
#include "insets/ExternalTransforms.cpp" 
#include "insets/RenderButton.cpp" 
#include "insets/RenderGraphic.cpp" 
#include "insets/RenderPreview.cpp" 
#include "insets/Inset.cpp" 
#include "insets/InsetArgument.cpp" 
#include "insets/InsetBibitem.cpp" 
#include "insets/InsetBibtex.cpp" 
#include "insets/InsetBox.cpp" 
#include "insets/InsetBranch.cpp" 
#include "insets/InsetCaption.cpp" 
#include "insets/InsetCitation.cpp" 
#include "insets/InsetCollapsable.cpp" 
#include "insets/InsetCommand.cpp" 
#include "insets/InsetCommandParams.cpp" 
#include "insets/InsetERT.cpp" 
#include "insets/InsetExternal.cpp" 
#include "insets/InsetFlex.cpp" 
#include "insets/InsetFloat.cpp" 
#include "insets/InsetFloatList.cpp" 
#include "insets/InsetFoot.cpp" 
#include "insets/InsetFootlike.cpp" 
#include "insets/InsetGraphicsParams.cpp" 
#include "insets/InsetGraphics.cpp" 
#include "insets/InsetHyperlink.cpp" 
#include "insets/InsetInclude.cpp" 
#include "insets/InsetIndex.cpp" 
#include "insets/InsetInfo.cpp" 
#include "insets/InsetLabel.cpp" 
#include "insets/InsetLayout.cpp" 
#include "insets/InsetLine.cpp" 
#include "insets/InsetListings.cpp" 
#include "insets/InsetListingsParams.cpp" 
#include "insets/InsetMarginal.cpp" 
#include "insets/InsetNewline.cpp" 
#include "insets/InsetNewpage.cpp" 
#include "insets/InsetNomencl.cpp" 
#include "insets/InsetNote.cpp" 
#include "insets/InsetPhantom.cpp" 
#include "insets/InsetPreview.cpp" 
#include "insets/InsetQuotes.cpp" 
#include "insets/InsetRef.cpp" 
#include "insets/InsetScript.cpp" 
#include "insets/InsetSpace.cpp" 
#include "insets/InsetSpecialChar.cpp" 
#include "insets/InsetTabular.cpp" 
#include "insets/InsetText.cpp" 
#include "insets/InsetTOC.cpp" 
#include "insets/InsetVSpace.cpp" 
#include "insets/InsetWrap.cpp"
